Package: gcipher
Version: 1.0-3.2
Severity: normal

/usr/share/gcipher/lib/MainCLI.py:34: GtkDeprecationWarning: gtk.mainloop is 
deprecated, use gtk.main instead
  gtk.mainloop()
/usr/share/gcipher/lib/LibGladeApplication.py:65: GtkDeprecationWarning: 
gtk.mainquit is deprecated, use gtk.main_quit instead
  gtk.mainquit()

Trivial patch attached.


-- System Information:
Debian Release: squeeze/sid
  APT prefers unstable
  APT policy: (500, 'unstable'), (500, 'testing')
Architecture: i386 (i686)

Kernel: Linux 2.6.26-2-686 (SMP w/2 CPU cores)
Locale: LANG=C, LC_CTYPE=C (charmap=ANSI_X3.4-1968)
Shell: /bin/sh linked to /bin/bash

Versions of packages gcipher depends on:
ii  python-glade2                 2.14.1-2   GTK+ bindings: Glade support
ii  python-gnome2                 2.26.1-1   Python bindings for the GNOME desk
ii  python-support                1.0.3      automated rebuilding support for P

gcipher recommends no packages.

gcipher suggests no packages.

-- no debconf information


Cheers,

-- 
Cristian
--- /usr/share/gcipher/lib/MainCLI.py.orig	2006-08-12 17:13:28.000000000 +0200
+++ /usr/share/gcipher/lib/MainCLI.py	2009-05-30 15:52:38.000000000 +0200
@@ -31,7 +31,7 @@
         from MainGUI import MainGUI
         gnome.program_init(Const.NAME, Const.VERSION)
         MainGUI()
-        gtk.mainloop() 
+        gtk.main() 
 
     def _runCommandLineApplication(self):
         """Run as a command-line application.
--- /usr/share/gcipher/lib/LibGladeApplication.py.orig	2006-08-12 17:13:28.000000000 +0200
+++ /usr/share/gcipher/lib/LibGladeApplication.py	2009-05-30 15:53:14.000000000 +0200
@@ -61,5 +61,5 @@
             (self.__class__.__name__, name))
 
     def on_quit_activate(self, *args):
-        """Ignore args and call gtk.mainquit()."""
-        gtk.mainquit()
+        """Ignore args and call gtk.main_quit()."""
+        gtk.main_quit()

Reply via email to